{% if discovered %}
<article>
    <header><strong>🔍 Found Apps</strong></header>
    <table>
        <thead>
            <tr>
                <th>App</th>
                <th>Type</th>
                <th>Sessions</th>
                <th>Path</th>
            </tr>
        </thead>
        <tbody>
        {% for src in discovered %}
            <tr>
                <td><strong>{{ src.name }}</strong></td>
                <td><kbd>{{ src.type }}</kbd></td>
                <td>{{ src.session_count }}</td>
                <td><code><small>{{ src.path }}</small></code></td>
            </tr>
        {% endfor %}
        </tbody>
    </table>
    <small>These apps were auto-detected on your machine.
    Edit your <code>brain.yaml</code> or <code>config.toml</code> to add/remove apps,
    then click "Update All" to import.</small>
</article>
{% else %}
<article>
    <p>No additional apps found on this machine.</p>
    <small>Supported: Claude Code, Clawdbot, Claude Desktop, ChatGPT exports</small>
</article>
{% endif %}
